==> haskell-juicypixels-3.2.9.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.9.5
id: JuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
key: JuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
indefinite: False
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
abi: 5bb8e1e1cf6fa227fb70cc80e55a12b5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/JuicyPixels-3.2.9.5
hs-libraries: HSJuicyPixels-3.2.9.5-ASGnSU2nyj8KgOo9KfthVh
include-dirs: /usr/lib/ghc-8.2.2/site-local/JuicyPixels-3.2.9.5/include
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    binary-0.8.5.1 zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY
    transformers-0.5.2.0 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo deepseq-1.4.3.0
    containers-0.5.10.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             zlib-0.6.2-FRkEyCRDCMJ4V7FViKOnGY=0435506582323b785ad7538064910d9e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=c6749b6f9516519305c703393b0c0693
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.2.9.5-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.9.5
id: JuicyPixels-3.2.9.5-3W6zdBkUHXg3jDowZKl8al
key: JuicyPixels-3.2.9.5-3W6zdBkUHXg3jDowZKl8al
license: BSD-3-Clause
maintainer: vincent.berthoux@gmail.com
author: Vincent Berthoux
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
abi: 5c666d89526f458bf7e3a13e5eff31d9
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
import-dirs: /usr/lib/ghc-8.4.2/site-local/JuicyPixels-3.2.9.5
library-dirs: /usr/lib/ghc-8.4.2/site-local/JuicyPixels-3.2.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/JuicyPixels-3.2.9.5
hs-libraries: HSJuicyPixels-3.2.9.5-3W6zdBkUHXg3jDowZKl8al
include-dirs: /usr/lib/ghc-8.4.2/site-local/JuicyPixels-3.2.9.5/include
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 binary-0.8.5.1
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH transformers-0.5.5.0
    vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb
    primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C deepseq-1.4.3.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             binary-0.8.5.1=253349ae905e3b03d89d37316bf920b7
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=de1ac2074f90e9397bcb253d3ffe265d
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             vector-0.12.0.1-4awQG9XUvVEBfJgKGHBhOb=6eab66b6328cb1f1f60a88d42282d4d0
             primitive-0.6.3.0-DaZpcxwJp2TGn8ITSgfI4C=16a73b69e52691069991327a53e4d794
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
